@@ -3,7 +3,7 @@
 //
 // Contents: Core routines that use connection handles shared between sqlsrv and pdo_sqlsrv
 //
-// Microsoft Drivers 5.11 for PHP for SQL Server
+// Microsoft Drivers 5.12 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -163,7 +163,9 @@ sqlsrv_conn* core_sqlsrv_connect( _In_ sqlsrv_context& henv_cp, _In_ sqlsrv_cont
         CHECK_CUSTOM_ERROR(conn->ce_option.enabled && conn->driver_version == ODBC_DRIVER::VER_13, conn, SQLSRV_ERROR_CE_DRIVER_REQUIRED, get_processor_arch(), NULL) {
             throw core::CoreException();
         }
-
+    if (conn->driver_version == ODBC_DRIVER::VER_13) {
+        zend_error(E_DEPRECATED, "ODBC driver version 13 is deprecated, please consider upgrading to the latest version.");
+    }
 #ifndef _WIN32
         // check if the ODBC driver actually exists, if not, throw an exception
         CHECK_CUSTOM_ERROR(!core_search_odbc_driver_unix(conn->driver_version), conn, SQLSRV_ERROR_SPECIFIED_DRIVER_NOT_FOUND) {
@@ -1145,10 +1147,8 @@ size_t core_str_zval_is_true(_Inout_ zval* value_z)
     if (found != std::string::npos)
         val_str.erase(found + 1);
 
-    const char TRUE_VALUE_1[] = "true";
-    const char TRUE_VALUE_2[] = "1";
     transform(val_str.begin(), val_str.end(), val_str.begin(), ::tolower);
-    if (!val_str.compare(TRUE_VALUE_1) || !val_str.compare(TRUE_VALUE_2)) {
+    if (!val_str.compare("true") || !val_str.compare("1") || !val_str.compare("yes")) {
         return 1; // true
     }
     return 0; // false
